@@ -4,7 +4,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.81';
+our $VERSION = '0.84';
 
 use utf8;
 use Encode;
@@ -78,7 +78,7 @@ sub new {
                         ( %{ $rel->{class} } )[1]
                         : $rel->{class};
 
-                   ### load $rel_class;
+                    #load $rel_class;
 
                     ### TODO: check for relation existing
                     while (my ($rel_key, $rel_opts) = each %{ $rel_class->_get_relations }) {
@@ -536,7 +536,7 @@ sub update {
     FIELD:
     for my $field (@$fields) {
         next FIELD if ! exists $params->{$field};
-        next FIELD if !$params->{$field};
+        next FIELD if ! $params->{$field};
 
         $self->$field($params->{$field});
     }
@@ -555,9 +555,18 @@ sub _insert {
                       ($self->can('_get_secondary_key')) ? $self->_get_secondary_key : undef;
 
     my $field_names_str = join q/, /, map { q/"/ . $_ . q/"/ } @field_names;
-    my $values          = join q/, /, map { '?' } @field_names;
-    my @bind            = map { $param->{$_} } @field_names;
 
+    my (@bind, @values_list);
+    for (@field_names) {
+        if (ref $param->{$_} eq 'SCALAR') {
+            push @values_list, ${ $param->{$_} };
+        }
+        else {
+            push @values_list, '?';
+            push @bind, $param->{$_};
+        }
+    }
+    my $values = join q/, /, @values_list;
     my $pkey_val;
     my $sql_stm = qq{
         INSERT INTO "$table_name" ($field_names_str)
@@ -610,8 +619,17 @@ sub _update {
     my $primary_key     = ($self->can('_get_primary_key')) ? $self->_get_primary_key :
                           ($self->can('_get_secondary_key')) ? $self->_get_secondary_key : undef;
 
-    my $setstring = join ', ', map { "$_ = ?" } @field_names;
-    my @bind = map { $param->{$_} } @field_names;
+    my (@set_list, @bind);
+    for (@field_names) {
+        if (ref $param->{$_} eq 'SCALAR') {
+            push @set_list, $_ . ' = ' . ${ $param->{$_} };
+        }
+        else {
+            push @set_list, "$_ = ?";
+            push @bind, $param->{$_};
+        }
+    }
+    my $setstring = join q/, /, @set_list;
     push @bind, $self->{$primary_key};
 
     my $sql_stm = ActiveRecord::Simple::Utils::quote_sql_stmt(
@@ -765,7 +783,7 @@ pattern. It's fast, very simple and very light.
 
     1;
 
-    # harcore:
+    # hardcore:
 
     package MyModel::Person;
     use base 'ActiveRecord::Simple';
@@ -786,6 +804,10 @@ pattern. It's fast, very simple and very light.
             data_type => 'varchar',
             size => 64,
             is_nullable => 0,
+        },
+        registered => {
+            data_type => 'timestamp',
+            is_nullable => 0,
         });
     __PACKAGE__->primary_key('id_person');
 
@@ -794,7 +816,8 @@ That's it! Now you're ready to use your active-record class in the application:
     use MyModel::Person;
 
     # to create a new record:
-    my $person = MyModel::Person->new({ name => 'Foo' })->save();
+    my $person = MyModel::Person->new({ name => 'Foo', registered => \'NOW()' })->save();
+    # (use a scalarref to pass non-quoted data to the database, as is).
 
     # to update the record:
     $person->name('Bar')->save();
